@@ -1,12 +1,9 @@
 #' Representations of vectors
 #' 
-#' @param obj  The vector to create a representation for
-#' @param ...  ignored
+#' @param obj    The vector to create a representation for
+#' @param ...    ignored
+#' @param items  The maximum number of items displayed. The default is given by the option \code{repr.vector.max.items}
 #' 
-#' @aliases
-#' repr_markdown.logical repr_markdown.integer repr_markdown.complex repr_markdown.numeric repr_markdown.factor repr_markdown.character repr_markdown.Date
-#'    repr_latex.logical    repr_latex.integer    repr_latex.complex    repr_latex.numeric    repr_latex.factor    repr_latex.character    repr_latex.Date
-#'     repr_html.logical     repr_html.integer     repr_html.complex     repr_html.numeric     repr_html.factor     repr_html.character     repr_html.Date
 #' @name repr_*.vector
 #' @include repr_list.r
 #' @include utils.r
@@ -21,8 +18,9 @@ repr_vector_generic <- function(
 	...,
 	numeric_item = named_item,
 	individual_wrap = NULL, # will be passed the vector items twice so needs 2 times %s
-	item_uses_numbers = FALSE, escape_fun = identity) {
-	
+	item_uses_numbers = FALSE, escape_fun = identity,
+	items = getOption('repr.vector.max.items')
+) {
 	if (length(vec) == 0) return('')
 	
 	nms <- names(vec)
@@ -31,7 +29,11 @@ repr_vector_generic <- function(
 	
 	qt <- is.character(vec) && getOption('repr.vector.quote')
 	# excape_fun is output format specific, encodeString ensures that non-printables come out as \-escapes
-	char_vec <- escape_fun(encodeString(as.character(vec), quote = if (qt) "'" else ''))
+	parts <- partition(length(vec), items)
+	charify <- function(part) escape_fun(encodeString(as.character(part), quote = if (qt) "'" else ''))
+	char_vec <-
+		if (is.null(parts)) charify(vec)
+		else c(charify(vec[parts$start]), ellip_h, charify(vec[parts$end]))
 	
 	if (!is.null(individual_wrap)) {
 		char_vec <- sprintf(individual_wrap, char_vec, char_vec)
@@ -67,21 +69,37 @@ repr_vector_generic <- function(
 
 # HTML --------------------------------------------------------------------
 
+list_style <- '<style>
+.list-inline {list-style: none; margin:0; padding: 0}
+.list-inline>li {display: inline-block}
+.list-inline>li:not(:last-child)::after {content: "\\00b7"; padding: 0 .5ex}
+</style>
+'
+def_style <- '<style>
+.dl-inline {width: auto; margin:0; padding: 0}
+.dl-inline>dt, .dl-inline>dd {float: none; width: auto; display: inline-block}
+.dl-inline>dt::after {content: ":\\0020"; padding-right: .5ex}
+.dl-inline>dt:not(:first-of-type) {padding-left: .5ex}
+</style>'
 
-repr_html_wrapper <- function(obj, individual_wrap, ...) repr_vector_generic(
+
+repr_html_wrapper <- function(obj, individual_wrap, items, ...) repr_vector_generic(
 	obj,
-	'\t<li>%s</li>\n',
-	'\t<dt>%s</dt>\n\t\t<dd>%s</dd>\n',
+	'<li>%s</li>',
+	'<dt>%s</dt><dd>%s</dd>',
 	'<strong>%s:</strong> %s',
-	'<ol class=list-inline>\n%s</ol>\n',
-	'<dl class=dl-horizontal>\n%s</dl>\n',
+	paste0(list_style, '<ol class=list-inline>%s</ol>\n'),
+	paste0(def_style, '<dl class=dl-inline>%s</dl>\n'),
 	escape_fun = html_escape,
-	individual_wrap = individual_wrap)
+	individual_wrap = individual_wrap,
+	items = items
+)
 
 
 #' @name repr_*.vector
 #' @export
-repr_html.logical <- function(obj, ...) repr_html_wrapper(obj, NULL, ...)
+repr_html.logical <- function(obj, ..., items = getOption('repr.vector.max.items'))
+	repr_html_wrapper(obj, NULL, items, ...)
 
 #' @name repr_*.vector
 #' @export
@@ -95,17 +113,14 @@ repr_html.complex <- repr_html.logical
 #' @export
 repr_html.numeric <- repr_html.logical
 
-#' @name repr_*.vector
-#' @export
-repr_html.factor <- repr_html.logical
-
 #' @name repr_*.vector
 #' @export
 repr_html.character <- repr_html.logical
 
 #' @name repr_*.vector
 #' @export
-repr_html.Date <- function(obj, ...) repr_html_wrapper(obj, '<time datetime="%s">%s</time>', ...)
+repr_html.Date <- function(obj, ..., items = getOption('repr.vector.max.items'))
+	repr_html_wrapper(obj, '<time datetime="%s">%s</time>', items, ...)
 
 
 
@@ -117,14 +132,16 @@ repr_html.Date <- function(obj, ...) repr_html_wrapper(obj, '<time datetime="%s"
 
 #' @name repr_*.vector
 #' @export
-repr_markdown.logical <- function(obj, ...) repr_vector_generic(
+repr_markdown.logical <- function(obj, ..., items = getOption('repr.vector.max.items')) repr_vector_generic(
 	html_escape_names(obj),
 	'%s. %s\n',
 	'%s\n:   %s',
 	'**%s:** %s',
 	'%s\n\n',
 	item_uses_numbers = TRUE,
-	escape_fun = html_escape)
+	escape_fun = html_escape,
+	items = items
+)
 
 #' @name repr_*.vector
 #' @export
@@ -138,10 +155,6 @@ repr_markdown.complex <- repr_markdown.logical
 #' @export
 repr_markdown.numeric <- repr_markdown.logical
 
-#' @name repr_*.vector
-#' @export
-repr_markdown.factor <- repr_markdown.logical
-
 #' @name repr_*.vector
 #' @export
 repr_markdown.character <- repr_markdown.logical
@@ -159,7 +172,7 @@ repr_markdown.Date <- repr_markdown.logical
 
 #' @name repr_*.vector
 #' @export
-repr_latex.logical <- function(obj, ...) repr_vector_generic(
+repr_latex.logical <- function(obj, ..., items = getOption('repr.vector.max.items')) repr_vector_generic(
 	latex_escape_names(obj),  # escape vector names, regardless of class
 	'\\item %s\n',
 	'\\item[%s] %s\n',
@@ -167,7 +180,9 @@ repr_latex.logical <- function(obj, ...) repr_vector_generic(
 	enum_wrap  = '\\begin{enumerate*}\n%s\\end{enumerate*}\n',
 	named_wrap = '\\begin{description*}\n%s\\end{description*}\n',
 	only_named_item = '\\textbf{%s:} %s',
-	escape_fun = latex_escape)
+	escape_fun = latex_escape,
+	items = items
+)
 
 #' @name repr_*.vector
 #' @export
@@ -181,10 +196,6 @@ repr_latex.complex <- repr_latex.logical
 #' @export
 repr_latex.numeric <- repr_latex.logical
 
-#' @name repr_*.vector
-#' @export
-repr_latex.factor <- repr_latex.logical
-
 #' @name repr_*.vector
 #' @export
 repr_latex.character <- repr_latex.logical
